Class: Aws::NimbleStudio::Types::CreateStreamingSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-nimblestudio/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instance_type ⇒ String

The EC2 Instance type used for the streaming session.

Returns:

  • (String)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#launch_profile_id ⇒ String

The ID of the launch profile used to control access from the streaming session.

Returns:

  • (String)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owned_by ⇒ String

The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.

Returns:

  • (String)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_image_id ⇒ String

The ID of the streaming image.

Returns:

  • (String)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#studio_id ⇒ String

The studio ID.

Returns:

  • (String)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A collection of labels, in the form of key-value pairs, that apply to this resource.

Returns:

  • (Hash<String,String>)


343
344
345
346
347
348
349
350
351
352
353
# File 'lib/aws-sdk-nimblestudio/types.rb', line 343

class CreateStreamingSessionRequest < Struct.new(
  :client_token,
  :ec2_instance_type,
  :launch_profile_id,
  :owned_by,
  :streaming_image_id,
  :studio_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end