Method: Aws::NimbleStudio::Types::LaunchProfileInitializationScript#runtime_role_arn

Defined in:
lib/aws-sdk-nimblestudio/types.rb

#runtime_role_arnString

An IAM role attached to a Studio Component that gives the studio component access to Amazon Web Services resources at anytime while the instance is running.



1558
1559
1560
1561
1562
1563
1564
1565
1566
# File 'lib/aws-sdk-nimblestudio/types.rb', line 1558

class LaunchProfileInitializationScript < Struct.new(
  :runtime_role_arn,
  :script,
  :secure_initialization_role_arn,
  :studio_component_id,
  :studio_component_name)
  SENSITIVE = [:script, :studio_component_name]
  include Aws::Structure
end