Class: Aws::NimbleStudio::Types::StreamConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::NimbleStudio::Types::StreamConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-nimblestudio/types.rb
Overview
A configuration for a streaming session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automatic_termination_mode ⇒ String
Indicates if a streaming session created from this launch profile should be terminated automatically or retained without termination after being in a
STOPPEDstate. -
#clipboard_mode ⇒ String
Allows or deactivates the use of the system clipboard to copy and paste between the streaming session and streaming client.
-
#ec2_instance_types ⇒ Array<String>
The EC2 instance types that users can select from when launching a streaming session with this launch profile.
-
#max_session_length_in_minutes ⇒ Integer
The length of time, in minutes, that a streaming session can be active before it is stopped or terminated.
-
#max_stopped_session_length_in_minutes ⇒ Integer
Integer that determines if you can start and stop your sessions and how long a session can stay in the
STOPPEDstate. -
#session_backup ⇒ Types::StreamConfigurationSessionBackup
Information about the streaming session backup.
-
#session_persistence_mode ⇒ String
Determine if a streaming session created from this launch profile can configure persistent storage.
-
#session_storage ⇒ Types::StreamConfigurationSessionStorage
The upload storage for a streaming session.
-
#streaming_image_ids ⇒ Array<String>
The streaming images that users can select from when launching a streaming session with this launch profile.
-
#volume_configuration ⇒ Types::VolumeConfiguration
Custom volume configuration for the root volumes that are attached to streaming sessions.
Instance Attribute Details
#automatic_termination_mode ⇒ String
Indicates if a streaming session created from this launch profile should be terminated automatically or retained without termination after being in a STOPPED state.
-
When
ACTIVATED, the streaming session is scheduled for termination after being in theSTOPPEDstate for the time specified inmaxStoppedSessionLengthInMinutes. -
When
DEACTIVATED, the streaming session can remain in theSTOPPEDstate indefinitely.
This parameter is only allowed when sessionPersistenceMode is ACTIVATED. When allowed, the default value for this parameter is DEACTIVATED.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#clipboard_mode ⇒ String
Allows or deactivates the use of the system clipboard to copy and paste between the streaming session and streaming client.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#ec2_instance_types ⇒ Array<String>
The EC2 instance types that users can select from when launching a streaming session with this launch profile.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#max_session_length_in_minutes ⇒ Integer
The length of time, in minutes, that a streaming session can be active before it is stopped or terminated. After this point, Nimble Studio automatically terminates or stops the session. The default length of time is 690 minutes, and the maximum length of time is 30 days.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#max_stopped_session_length_in_minutes ⇒ Integer
Integer that determines if you can start and stop your sessions and how long a session can stay in the STOPPED state. The default value is 0. The maximum value is 5760.
This field is allowed only when sessionPersistenceMode is ACTIVATED and automaticTerminationMode is ACTIVATED.
If the value is set to 0, your sessions can’t be STOPPED. If you then call StopStreamingSession, the session fails. If the time that a session stays in the READY state exceeds the maxSessionLengthInMinutes value, the session will automatically be terminated (instead of STOPPED).
If the value is set to a positive number, the session can be stopped. You can call StopStreamingSession to stop sessions in the READY state. If the time that a session stays in the READY state exceeds the maxSessionLengthInMinutes value, the session will automatically be stopped (instead of terminated).
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#session_backup ⇒ Types::StreamConfigurationSessionBackup
Information about the streaming session backup.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#session_persistence_mode ⇒ String
Determine if a streaming session created from this launch profile can configure persistent storage. This means that volumeConfiguration and automaticTerminationMode are configured.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#session_storage ⇒ Types::StreamConfigurationSessionStorage
The upload storage for a streaming session.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#streaming_image_ids ⇒ Array<String>
The streaming images that users can select from when launching a streaming session with this launch profile.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |
#volume_configuration ⇒ Types::VolumeConfiguration
Custom volume configuration for the root volumes that are attached to streaming sessions.
This parameter is only allowed when sessionPersistenceMode is ACTIVATED.
2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2536 class StreamConfiguration < Struct.new( :automatic_termination_mode, :clipboard_mode, :ec2_instance_types, :max_session_length_in_minutes, :max_stopped_session_length_in_minutes, :session_backup, :session_persistence_mode, :session_storage, :streaming_image_ids, :volume_configuration) SENSITIVE = [] include Aws::Structure end |