Class: Aws::NimbleStudio::Types::StreamConfigurationSessionBackup
- Inherits:
-
Struct
- Object
- Struct
- Aws::NimbleStudio::Types::StreamConfigurationSessionBackup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-nimblestudio/types.rb
Overview
Configures how streaming sessions are backed up when launched from this launch profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_backups_to_retain ⇒ Integer
The maximum number of backups that each streaming session created from this launch profile can have.
-
#mode ⇒ String
Specifies how artists sessions are backed up.
Instance Attribute Details
#max_backups_to_retain ⇒ Integer
The maximum number of backups that each streaming session created from this launch profile can have.
2675 2676 2677 2678 2679 2680 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2675 class StreamConfigurationSessionBackup < Struct.new( :max_backups_to_retain, :mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Specifies how artists sessions are backed up.
Configures backups for streaming sessions launched with this launch profile. The default value is DEACTIVATED, which means that backups are deactivated. To allow backups, set this value to AUTOMATIC.
2675 2676 2677 2678 2679 2680 |
# File 'lib/aws-sdk-nimblestudio/types.rb', line 2675 class StreamConfigurationSessionBackup < Struct.new( :max_backups_to_retain, :mode) SENSITIVE = [] include Aws::Structure end |