Class: Aws::NimbleStudio::Types::StreamingSessionStream

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-nimblestudio/types.rb

Overview

A stream is an active connection to a streaming session, enabling a studio user to control the streaming session using a compatible client. Streaming session streams are compatible with the NICE DCV web client, included in the Nimble Studio portal, or the NICE DCV desktop client.

Constant Summary collapse

SENSITIVE =
[:url]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The ISO timestamp in seconds for when the resource was created.

Returns:

  • (Time)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#created_by ⇒ String

The user ID of the user that created the streaming session stream.

Returns:

  • (String)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#expires_at ⇒ Time

The ISO timestamp in seconds for when the resource expires.

Returns:

  • (Time)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#owned_by ⇒ String

The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.

Returns:

  • (String)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#state ⇒ String

The current state.

Returns:

  • (String)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#status_code ⇒ String

The streaming session stream status code.

Returns:

  • (String)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#stream_id ⇒ String

The stream ID.

Returns:

  • (String)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end

#url ⇒ String

The URL to connect to this stream using the DCV client.

Returns:

  • (String)


3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3111

class StreamingSessionStream < Struct.new(
  :created_at,
  :created_by,
  :expires_at,
  :owned_by,
  :state,
  :status_code,
  :stream_id,
  :url)
  SENSITIVE = [:url]
  include Aws::Structure
end