Class: Aws::NimbleStudio::Types::StudioComponentSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-nimblestudio/types.rb

Overview

The studio component's summary.

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The ISO timestamp in seconds for when the resource was created.

Returns:

  • (Time)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_by ⇒ String

The user ID of the user that created the studio component.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#description ⇒ String

The description.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#name ⇒ String

The name for the studio component.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#studio_component_id ⇒ String

The unique identifier for a studio component resource.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#subtype ⇒ String

The specific subtype of a studio component.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#type ⇒ String

The type of the studio component.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#updated_at ⇒ Time

The ISO timestamp in seconds for when the resource was updated.

Returns:

  • (Time)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#updated_by ⇒ String

The user ID of the user that most recently updated the resource.

Returns:

  • (String)


3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
# File 'lib/aws-sdk-nimblestudio/types.rb', line 3483

class StudioComponentSummary < Struct.new(
  :created_at,
  :created_by,
  :description,
  :name,
  :studio_component_id,
  :subtype,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end